//Accelerometer Code From: https://www.electronicwings.com/arduino/adxl335-accelerometer-interfacing-with-arduino-uno

#include <math.h>
const int x_out = A1; /* connect x_out of module to A1 of UNO board */
const int y_out = A2; /* connect y_out of module to A2 of UNO board */
const int z_out = A3; /* connect z_out of module to A3 of UNO board */

const int transducer01 = 10;
const int transducer02 = 11;
const int transducer03 = 9;

int nice = 100;
int gentle = 195;
int mean = 255;

int patienceCounter = 0;
long forgivenessTimer = 3000;

void setup() {
  Serial.begin(9600); 

  pinMode(transducer01, OUTPUT);
  pinMode(transducer02, OUTPUT);
  pinMode(transducer03, OUTPUT);  
}

void loop() {
  long now = micros();
    
  if (now > forgivenessTimer && patienceCounter > 0) {
    forgivenessTimer = now + forgivenessTimer;
    patienceCounter--;
  }
  
  int x_adc_value, y_adc_value, z_adc_value; 
  double x_g_value, y_g_value, z_g_value;
  double roll, pitch, yaw;
  x_adc_value = analogRead(x_out); /* Digital value of voltage on x_out pin */ 
  y_adc_value = analogRead(y_out); /* Digital value of voltage on y_out pin */ 
  z_adc_value = analogRead(z_out); /* Digital value of voltage on z_out pin */ 
  Serial.print("x = ");
  Serial.print(x_adc_value);
  Serial.print("\t\t");
  Serial.print("y = ");
  Serial.print(y_adc_value);
  Serial.print("\t\t");
  Serial.print("z = ");
  Serial.print(z_adc_value);
  Serial.print("\t\t");
  //delay(100);
  
  x_g_value = ( ( ( (double)(x_adc_value * 5)/1024) - 1.65 ) / 0.330 ); /* Acceleration in x-direction in g units */ 
  y_g_value = ( ( ( (double)(y_adc_value * 5)/1024) - 1.65 ) / 0.330 ); /* Acceleration in y-direction in g units */ 
  z_g_value = ( ( ( (double)(z_adc_value * 5)/1024) - 1.80 ) / 0.330 ); /* Acceleration in z-direction in g units */ 

  roll = ( ( (atan2(y_g_value,z_g_value) * 180) / 3.14 ) + 180 ); /* Formula for roll */
  pitch = ( ( (atan2(z_g_value,x_g_value) * 180) / 3.14 ) + 180 ); /* Formula for pitch */
  //yaw = ( ( (atan2(x_g_value,y_g_value) * 180) / 3.14 ) + 180 ); /* Formula for yaw */
  /* Not possible to measure yaw using accelerometer. Gyroscope must be used if yaw is also required */

  Serial.print("Pitch = ");
  Serial.print(roll);
  Serial.print("\t");

  Serial.print("Patience Counter = ");
  Serial.println(patienceCounter);

  
  if (roll < 30 || roll > 90) {
    for (int fadeValue = 0 ; fadeValue <= nice; fadeValue += 5) {
    // sets the value (range from 0 to 255):
      analogWrite(transducer01, fadeValue);
      analogWrite(transducer02, fadeValue);
      analogWrite(transducer03, fadeValue);
    // wait for 30 milliseconds to see the dimming effect
      delay(30);
    }
  // fade out from max to min in increments of 5 points:
    for (int fadeValue = nice; fadeValue >= 0; fadeValue -= 5) {
    // sets the value (range from 0 to 255):
      analogWrite(transducer01, fadeValue);
      analogWrite(transducer02, fadeValue);
      analogWrite(transducer03, fadeValue);
    // wait for 30 milliseconds to see the dimming effect
      delay(30);
    }
  }
  
  if (roll > 30 && roll < 55 && patienceCounter < 25) {
    analogWrite(transducer01, gentle);
    delay(100);
    analogWrite(transducer02, gentle);
    analogWrite(transducer01, 0);
    delay(100);
    analogWrite(transducer03, gentle);
    analogWrite(transducer02, 0);
    delay(100);
    analogWrite(transducer03, 0);
    patienceCounter++;
  }
  
  if (roll > 65 && roll < 90 && patienceCounter < 25) {
    analogWrite(transducer03, gentle);
    delay(100);
    analogWrite(transducer02, gentle);
    analogWrite(transducer03, 0);
    delay(100);
    analogWrite(transducer01, gentle);
    analogWrite(transducer02, 0);
    delay(100);
    analogWrite(transducer01, 0);
    patienceCounter++;  
  }
  
  if (roll > 30 && roll < 55 && patienceCounter > 24) {
    analogWrite(transducer01, mean);
    analogWrite(transducer02, mean);
    analogWrite(transducer03, mean);
    delay(100);
    analogWrite(transducer01, 0);
    analogWrite(transducer02, 0);
    analogWrite(transducer03, 0);
  }
  
  if (roll > 65 && roll < 90 && patienceCounter > 24) {
    analogWrite(transducer01, mean);
    analogWrite(transducer02, mean);
    analogWrite(transducer03, mean);
    delay(100);
    analogWrite(transducer01, 0);
    analogWrite(transducer02, 0);
    analogWrite(transducer03, 0);
  }
  
}
